@@ -3,7 +3,7 @@ import os
 
 from notetool.secret import read_secret
 from sqlalchemy import create_engine
-from sqlalchemy.orm import declarative_base, sessionmaker
+from sqlalchemy.orm import declarative_base, scoped_session, sessionmaker
 
 
 class BaseTable(object):
@@ -17,7 +17,11 @@ uri = uri or f'sqlite:///{os.path.abspath(os.path.dirname(__file__))}/data/notec
 #engine = create_engine(uri, echo=True)
 engine = create_engine(uri)
 Base = declarative_base()
-session = sessionmaker(bind=engine)()
+session = scoped_session(sessionmaker(
+    autocommit=True,
+    # autoflush=True,
+    bind=engine))
+
 
 logging.info(f'uri:{uri}')
 
